from setuptools import setup

setup(name='funny_1965',
      version='0.1',
      description='The funniest joke in the world',
      url='http://github.com/BeshoyAnwar/funny_1965',
      author='Flying Circus',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['funny_1965'],
      zip_safe=False)